@@ -151,9 +151,9 @@ var NAVTREE =
       [ "The overall HTML output looks different, while I only wanted to use my own html header file", "faq.html#faq_html_header", null ],
       [ "Why does Doxygen use Qt?", "faq.html#faq_use_qt", null ],
       [ "How can I exclude all test directories from my directory tree?", "faq.html#faq_excl_dir", null ],
-      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text....", "faq.html#faq_class", null ],
+      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text. How do I prevent that at a certain place?", "faq.html#faq_class", null ],
       [ "My favorite programming language is X. Can I still use Doxygen?", "faq.html#faq_pgm_X", null ],
-      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJ...", "faq.html#faq_lex", null ],
+      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJECT\"", "faq.html#faq_lex", null ],
       [ "When running make in the latex directory I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
       [ "Why are dependencies via STL classes not shown in the dot graphs?", "faq.html#faq_stl", null ],
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
@@ -210,7 +210,7 @@ var NAVTREE =
     ] ],
     [ "Special Commands", "commands.html", [
       [ "Introduction", "commands.html#cmd_intro", null ],
-      [ "\\addtogroup <name> [(title)]", "commands.html#cmdaddtogroup", null ],
+      [ "\\addtogroup &lt;name&gt; [(title)]", "commands.html#cmdaddtogroup", null ],
       [ "\\callgraph", "commands.html#cmdcallgraph", null ],
       [ "\\hidecallgraph", "commands.html#cmdhidecallgraph", null ],
       [ "\\callergraph", "commands.html#cmdcallergraph", null ],
@@ -235,58 +235,58 @@ var NAVTREE =
       [ "\\hidegroupgraph", "commands.html#cmdhidegroupgraph", null ],
       [ "\\showenumvalues", "commands.html#cmdshowenumvalues", null ],
       [ "\\hideenumvalues", "commands.html#cmdhideenumvalues", null ],
-      [ "\\qualifier <label> | \"(text)\"", "commands.html#cmdqualifier", null ],
-      [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
-      [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
-      [ "\\concept <name>", "commands.html#cmdconcept", null ],
-      [ "\\def <name>", "commands.html#cmddef", null ],
-      [ "\\defgroup <name> (group title)", "commands.html#cmddefgroup", null ],
-      [ "\\dir [<path fragment>]", "commands.html#cmddir", null ],
-      [ "\\enum <name>", "commands.html#cmdenum", null ],
-      [ "\\example['{lineno}'] <file-name>", "commands.html#cmdexample", null ],
+      [ "\\qualifier &lt;label&gt; | \"(text)\"", "commands.html#cmdqualifier", null ],
+      [ "\\category &lt;name&gt; [&lt;header-file&gt;] [&lt;header-name&gt;]", "commands.html#cmdcategory", null ],
+      [ "\\class &lt;name&gt; [&lt;header-file&gt;] [&lt;header-name&gt;]", "commands.html#cmdclass", null ],
+      [ "\\concept &lt;name&gt;", "commands.html#cmdconcept", null ],
+      [ "\\def &lt;name&gt;", "commands.html#cmddef", null ],
+      [ "\\defgroup &lt;name&gt; (group title)", "commands.html#cmddefgroup", null ],
+      [ "\\dir [&lt;path fragment&gt;]", "commands.html#cmddir", null ],
+      [ "\\enum &lt;name&gt;", "commands.html#cmdenum", null ],
+      [ "\\example['{lineno}'] &lt;file-name&gt;", "commands.html#cmdexample", null ],
       [ "\\endinternal", "commands.html#cmdendinternal", null ],
-      [ "\\extends <name>", "commands.html#cmdextends", null ],
-      [ "\\file [<name>]", "commands.html#cmdfile", null ],
+      [ "\\extends &lt;name&gt;", "commands.html#cmdextends", null ],
+      [ "\\file [&lt;name&gt;]", "commands.html#cmdfile", null ],
       [ "\\fileinfo['{'option'}']", "commands.html#cmdfileinfo", null ],
       [ "\\lineinfo", "commands.html#cmdlineinfo", null ],
       [ "\\fn (function declaration)", "commands.html#cmdfn", null ],
-      [ "\\headerfile <header-file> [<header-name>]", "commands.html#cmdheaderfile", null ],
+      [ "\\headerfile &lt;header-file&gt; [&lt;header-name&gt;]", "commands.html#cmdheaderfile", null ],
       [ "\\hideinitializer", "commands.html#cmdhideinitializer", null ],
-      [ "\\idlexcept <name>", "commands.html#cmdidlexcept", null ],
-      [ "\\implements <name>", "commands.html#cmdimplements", null ],
-      [ "\\ingroup (<groupname> [<groupname>]*)", "commands.html#cmdingroup", null ],
-      [ "\\interface <name> [<header-file>] [<header-name>]", "commands.html#cmdinterface", null ],
+      [ "\\idlexcept &lt;name&gt;", "commands.html#cmdidlexcept", null ],
+      [ "\\implements &lt;name&gt;", "commands.html#cmdimplements", null ],
+      [ "\\ingroup (&lt;groupname&gt; [&lt;groupname&gt;]*)", "commands.html#cmdingroup", null ],
+      [ "\\interface &lt;name&gt; [&lt;header-file&gt;] [&lt;header-name&gt;]", "commands.html#cmdinterface", null ],
       [ "\\internal", "commands.html#cmdinternal", null ],
       [ "\\mainpage [(title)]", "commands.html#cmdmainpage", null ],
-      [ "\\memberof <name>", "commands.html#cmdmemberof", null ],
-      [ "\\module <name>", "commands.html#cmdmodule", null ],
+      [ "\\memberof &lt;name&gt;", "commands.html#cmdmemberof", null ],
+      [ "\\module &lt;name&gt;", "commands.html#cmdmodule", null ],
       [ "\\name [(header)]", "commands.html#cmdname", null ],
-      [ "\\namespace <name>", "commands.html#cmdnamespace", null ],
+      [ "\\namespace &lt;name&gt;", "commands.html#cmdnamespace", null ],
       [ "\\nosubgrouping", "commands.html#cmdnosubgrouping", null ],
       [ "\\overload [(function declaration)]", "commands.html#cmdoverload", null ],
-      [ "\\package <name>", "commands.html#cmdpackage", null ],
-      [ "\\page <name> (title)", "commands.html#cmdpage", null ],
+      [ "\\package &lt;name&gt;", "commands.html#cmdpackage", null ],
+      [ "\\page &lt;name&gt; (title)", "commands.html#cmdpage", null ],
       [ "\\private", "commands.html#cmdprivate", null ],
       [ "\\privatesection", "commands.html#cmdprivatesection", null ],
       [ "\\property (qualified property name)", "commands.html#cmdproperty", null ],
       [ "\\protected", "commands.html#cmdprotected", null ],
       [ "\\protectedsection", "commands.html#cmdprotectedsection", null ],
-      [ "\\protocol <name> [<header-file>] [<header-name>]", "commands.html#cmdprotocol", null ],
+      [ "\\protocol &lt;name&gt; [&lt;header-file&gt;] [&lt;header-name&gt;]", "commands.html#cmdprotocol", null ],
       [ "\\public", "commands.html#cmdpublic", null ],
       [ "\\publicsection", "commands.html#cmdpublicsection", null ],
       [ "\\pure", "commands.html#cmdpure", null ],
-      [ "\\relates <name>", "commands.html#cmdrelates", null ],
-      [ "\\related <name>", "commands.html#cmdrelated", null ],
-      [ "\\relatesalso <name>", "commands.html#cmdrelatesalso", null ],
-      [ "\\relatedalso <name>", "commands.html#cmdrelatedalso", null ],
+      [ "\\relates &lt;name&gt;", "commands.html#cmdrelates", null ],
+      [ "\\related &lt;name&gt;", "commands.html#cmdrelated", null ],
+      [ "\\relatesalso &lt;name&gt;", "commands.html#cmdrelatesalso", null ],
+      [ "\\relatedalso &lt;name&gt;", "commands.html#cmdrelatedalso", null ],
       [ "\\showinitializer", "commands.html#cmdshowinitializer", null ],
       [ "\\static", "commands.html#cmdstatic", null ],
-      [ "\\struct <name> [<header-file>] [<header-name>]", "commands.html#cmdstruct", null ],
+      [ "\\struct &lt;name&gt; [&lt;header-file&gt;] [&lt;header-name&gt;]", "commands.html#cmdstruct", null ],
       [ "\\typedef (typedef declaration)", "commands.html#cmdtypedef", null ],
-      [ "\\union <name> [<header-file>] [<header-name>]", "commands.html#cmdunion", null ],
+      [ "\\union &lt;name&gt; [&lt;header-file&gt;] [&lt;header-name&gt;]", "commands.html#cmdunion", null ],
       [ "\\var (variable declaration)", "commands.html#cmdvar", null ],
       [ "\\vhdlflow [(title for the flow chart)]", "commands.html#cmdvhdlflow", null ],
-      [ "\\weakgroup <name> [(title)]", "commands.html#cmdweakgroup", null ],
+      [ "\\weakgroup &lt;name&gt; [(title)]", "commands.html#cmdweakgroup", null ],
       [ "\\attention { attention text }", "commands.html#cmdattention", null ],
       [ "\\author { list of authors }", "commands.html#cmdauthor", null ],
       [ "\\authors { list of authors }", "commands.html#cmdauthors", null ],
@@ -295,7 +295,7 @@ var NAVTREE =
       [ "\\cond [(section-label)]", "commands.html#cmdcond", null ],
       [ "\\copyright { copyright description }", "commands.html#cmdcopyright", null ],
       [ "\\date { date description }", "commands.html#cmddate", null ],
-      [ "\\showdate \"<format>\" [ <date_time> ]", "commands.html#cmdshowdate", null ],
+      [ "\\showdate \"&lt;format&gt;\" [ &lt;date_time&gt; ]", "commands.html#cmdshowdate", null ],
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
       [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
@@ -304,17 +304,17 @@ var NAVTREE =
       [ "\\elseif (section-label)", "commands.html#cmdelseif", null ],
       [ "\\endcond", "commands.html#cmdendcond", null ],
       [ "\\endif", "commands.html#cmdendif", null ],
-      [ "\\exception <exception-object> { exception description }", "commands.html#cmdexception", null ],
+      [ "\\exception &lt;exception-object&gt; { exception description }", "commands.html#cmdexception", null ],
       [ "\\if (section-label)", "commands.html#cmdif", null ],
       [ "\\ifnot (section-label)", "commands.html#cmdifnot", null ],
       [ "\\important { important text }", "commands.html#cmdimportant", null ],
       [ "\\invariant { description of invariant }", "commands.html#cmdinvariant", null ],
       [ "\\note { text }", "commands.html#cmdnote", null ],
       [ "\\par [(paragraph title)] { paragraph }", "commands.html#cmdpar", null ],
-      [ "\\param[<dir>] <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
+      [ "\\param[&lt;dir&gt;] &lt;parameter-name&gt; { parameter description }", "commands.html#cmdparam", null ],
       [ "\\parblock", "commands.html#cmdparblock", null ],
       [ "\\endparblock", "commands.html#cmdendparblock", null ],
-      [ "\\tparam <template-parameter-name> { description }", "commands.html#cmdtparam", null ],
+      [ "\\tparam &lt;template-parameter-name&gt; { description }", "commands.html#cmdtparam", null ],
       [ "\\post { description of the postcondition }", "commands.html#cmdpost", null ],
       [ "\\pre { description of the precondition }", "commands.html#cmdpre", null ],
       [ "\\remark { remark text }", "commands.html#cmdremark", null ],
@@ -322,78 +322,78 @@ var NAVTREE =
       [ "\\result { description of the result value }", "commands.html#cmdresult", null ],
       [ "\\return { description of the return value }", "commands.html#cmdreturn", null ],
       [ "\\returns { description of the return value }", "commands.html#cmdreturns", null ],
-      [ "\\retval <return value> { description }", "commands.html#cmdretval", null ],
+      [ "\\retval &lt;return value&gt; { description }", "commands.html#cmdretval", null ],
       [ "\\sa { references }", "commands.html#cmdsa", null ],
       [ "\\see { references }", "commands.html#cmdsee", null ],
       [ "\\short { short description }", "commands.html#cmdshort", null ],
       [ "\\since { text }", "commands.html#cmdsince", null ],
       [ "\\test { paragraph describing a test case }", "commands.html#cmdtest", null ],
-      [ "\\throw <exception-object> { exception description }", "commands.html#cmdthrow", null ],
-      [ "\\throws <exception-object> { exception description }", "commands.html#cmdthrows", null ],
+      [ "\\throw &lt;exception-object&gt; { exception description }", "commands.html#cmdthrow", null ],
+      [ "\\throws &lt;exception-object&gt; { exception description }", "commands.html#cmdthrows", null ],
       [ "\\todo { paragraph describing what is to be done }", "commands.html#cmdtodo", null ],
       [ "\\version { version number }", "commands.html#cmdversion", null ],
       [ "\\warning { warning message }", "commands.html#cmdwarning", null ],
-      [ "\\xrefitem <key> \"heading\" \"list title\" { text }", "commands.html#cmdxrefitem", null ],
+      [ "\\xrefitem &lt;key&gt; \"heading\" \"list title\" { text }", "commands.html#cmdxrefitem", null ],
       [ "\\addindex (text)", "commands.html#cmdaddindex", null ],
-      [ "\\anchor <word>", "commands.html#cmdanchor", null ],
-      [ "\\cite <label>", "commands.html#cmdcite", null ],
+      [ "\\anchor &lt;word&gt;", "commands.html#cmdanchor", null ],
+      [ "\\cite['{'[option]'}'] &lt;label&gt;", "commands.html#cmdcite", null ],
       [ "\\endlink", "commands.html#cmdendlink", null ],
-      [ "\\link <link-object>", "commands.html#cmdlink", null ],
-      [ "\\ref <name> [\"(text)\"]", "commands.html#cmdref", null ],
-      [ "\\refitem <name>", "commands.html#cmdrefitem", null ],
+      [ "\\link &lt;link-object&gt;", "commands.html#cmdlink", null ],
+      [ "\\ref &lt;name&gt; [\"(text)\"]", "commands.html#cmdref", null ],
+      [ "\\refitem &lt;name&gt;", "commands.html#cmdrefitem", null ],
       [ "\\secreflist", "commands.html#cmdsecreflist", null ],
       [ "\\endsecreflist", "commands.html#cmdendsecreflist", null ],
-      [ "\\subpage <name> [\"(text)\"]", "commands.html#cmdsubpage", null ],
+      [ "\\subpage &lt;name&gt; [\"(text)\"]", "commands.html#cmdsubpage", null ],
       [ "\\tableofcontents['{'[option[:level]][,option[:level]]*'}']", "commands.html#cmdtableofcontents", null ],
-      [ "\\section <section-name> (section title)", "commands.html#cmdsection", null ],
-      [ "\\subsection <subsection-name> (subsection title)", "commands.html#cmdsubsection", null ],
-      [ "\\subsubsection <subsubsection-name> (subsubsection title)", "commands.html#cmdsubsubsection", null ],
-      [ "\\paragraph <paragraph-name> (paragraph title)", "commands.html#cmdparagraph", null ],
-      [ "\\subparagraph <subparagraph-name> (subparagraph title)", "commands.html#cmdsubparagraph", null ],
-      [ "\\subsubparagraph <subsubparagraph-name> (subsubparagraph title)", "commands.html#cmdsubsubparagraph", null ],
-      [ "\\dontinclude['{lineno}'] <file-name>", "commands.html#cmddontinclude", null ],
-      [ "\\include['{'option'}'] <file-name>", "commands.html#cmdinclude", null ],
-      [ "\\includelineno <file-name>", "commands.html#cmdincludelineno", null ],
-      [ "\\includedoc['{'option'}'] <file-name>", "commands.html#cmdincludedoc", null ],
+      [ "\\section &lt;section-name&gt; (section title)", "commands.html#cmdsection", null ],
+      [ "\\subsection &lt;subsection-name&gt; (subsection title)", "commands.html#cmdsubsection", null ],
+      [ "\\subsubsection &lt;subsubsection-name&gt; (subsubsection title)", "commands.html#cmdsubsubsection", null ],
+      [ "\\paragraph &lt;paragraph-name&gt; (paragraph title)", "commands.html#cmdparagraph", null ],
+      [ "\\subparagraph &lt;subparagraph-name&gt; (subparagraph title)", "commands.html#cmdsubparagraph", null ],
+      [ "\\subsubparagraph &lt;subsubparagraph-name&gt; (subsubparagraph title)", "commands.html#cmdsubsubparagraph", null ],
+      [ "\\dontinclude['{lineno}'] &lt;file-name&gt;", "commands.html#cmddontinclude", null ],
+      [ "\\include['{'option'}'] &lt;file-name&gt;", "commands.html#cmdinclude", null ],
+      [ "\\includelineno &lt;file-name&gt;", "commands.html#cmdincludelineno", null ],
+      [ "\\includedoc['{'option'}'] &lt;file-name&gt;", "commands.html#cmdincludedoc", null ],
       [ "\\line ( pattern )", "commands.html#cmdline", null ],
       [ "\\skip ( pattern )", "commands.html#cmdskip", null ],
       [ "\\skipline ( pattern )", "commands.html#cmdskipline", null ],
-      [ "\\snippet['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippet", null ],
-      [ "\\snippetlineno <file-name> ( block_id )", "commands.html#cmdsnippetlineno", null ],
-      [ "\\snippetdoc['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippetdoc", null ],
+      [ "\\snippet['{'option'}'] &lt;file-name&gt; ( block_id )", "commands.html#cmdsnippet", null ],
+      [ "\\snippetlineno &lt;file-name&gt; ( block_id )", "commands.html#cmdsnippetlineno", null ],
+      [ "\\snippetdoc['{'option'}'] &lt;file-name&gt; ( block_id )", "commands.html#cmdsnippetdoc", null ],
       [ "\\until ( pattern )", "commands.html#cmduntil", null ],
-      [ "\\verbinclude <file-name>", "commands.html#cmdverbinclude", null ],
-      [ "\\htmlinclude['[block]'] <file-name>", "commands.html#cmdhtmlinclude", null ],
-      [ "\\latexinclude <file-name>", "commands.html#cmdlatexinclude", null ],
-      [ "\\rtfinclude <file-name>", "commands.html#cmdrtfinclude", null ],
-      [ "\\maninclude <file-name>", "commands.html#cmdmaninclude", null ],
-      [ "\\docbookinclude <file-name>", "commands.html#cmddocbookinclude", null ],
-      [ "\\xmlinclude <file-name>", "commands.html#cmdxmlinclude", null ],
-      [ "\\a <word>", "commands.html#cmda", null ],
+      [ "\\verbinclude &lt;file-name&gt;", "commands.html#cmdverbinclude", null ],
+      [ "\\htmlinclude['[block]'] &lt;file-name&gt;", "commands.html#cmdhtmlinclude", null ],
+      [ "\\latexinclude &lt;file-name&gt;", "commands.html#cmdlatexinclude", null ],
+      [ "\\rtfinclude &lt;file-name&gt;", "commands.html#cmdrtfinclude", null ],
+      [ "\\maninclude &lt;file-name&gt;", "commands.html#cmdmaninclude", null ],
+      [ "\\docbookinclude &lt;file-name&gt;", "commands.html#cmddocbookinclude", null ],
+      [ "\\xmlinclude &lt;file-name&gt;", "commands.html#cmdxmlinclude", null ],
+      [ "\\a &lt;word&gt;", "commands.html#cmda", null ],
       [ "\\arg { item-description }", "commands.html#cmdarg", null ],
-      [ "\\b <word>", "commands.html#cmdb", null ],
-      [ "\\c <word>", "commands.html#cmdc", null ],
-      [ "\\code['{'<word>'}']", "commands.html#cmdcode", null ],
-      [ "\\copydoc <link-object>", "commands.html#cmdcopydoc", null ],
-      [ "\\copybrief <link-object>", "commands.html#cmdcopybrief", null ],
-      [ "\\copydetails <link-object>", "commands.html#cmdcopydetails", null ],
+      [ "\\b &lt;word&gt;", "commands.html#cmdb", null ],
+      [ "\\c &lt;word&gt;", "commands.html#cmdc", null ],
+      [ "\\code['{'&lt;word&gt;'}']", "commands.html#cmdcode", null ],
+      [ "\\copydoc &lt;link-object&gt;", "commands.html#cmdcopydoc", null ],
+      [ "\\copybrief &lt;link-object&gt;", "commands.html#cmdcopybrief", null ],
+      [ "\\copydetails &lt;link-object&gt;", "commands.html#cmdcopydetails", null ],
       [ "\\docbookonly", "commands.html#cmddocbookonly", null ],
-      [ "\\dot [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddot", null ],
+      [ "\\dot [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmddot", null ],
       [ "\\emoji \"name\"", "commands.html#cmdemoji", null ],
-      [ "\\msc [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmsc", null ],
-      [ "\\startuml ['{'option[,option]'}'] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
-      [ "\\dotfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddotfile", null ],
-      [ "\\mscfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmscfile", null ],
-      [ "\\diafile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddiafile", null ],
-      [ "\\doxyconfig <config_option>", "commands.html#cmddoxyconfig", null ],
-      [ "\\e <word>", "commands.html#cmde", null ],
-      [ "\\em <word>", "commands.html#cmdem", null ],
+      [ "\\msc [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmdmsc", null ],
+      [ "\\startuml ['{'option[,option]'}'] [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmdstartuml", null ],
+      [ "\\dotfile &lt;file&gt; [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmddotfile", null ],
+      [ "\\mscfile &lt;file&gt; [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmdmscfile", null ],
+      [ "\\diafile &lt;file&gt; [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmddiafile", null ],
+      [ "\\doxyconfig &lt;config_option&gt;", "commands.html#cmddoxyconfig", null ],
+      [ "\\e &lt;word&gt;", "commands.html#cmde", null ],
+      [ "\\em &lt;word&gt;", "commands.html#cmdem", null ],
       [ "\\endcode", "commands.html#cmdendcode", null ],
       [ "\\enddocbookonly", "commands.html#cmdenddocbookonly", null ],
       [ "\\enddot", "commands.html#cmdenddot", null ],
       [ "\\endmsc", "commands.html#cmdendmsc", null ],
       [ "\\enduml", "commands.html#cmdenduml", null ],
-      [ "\\plantumlfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdplantumlfile", null ],
+      [ "\\plantumlfile &lt;file&gt; [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmdplantumlfile", null ],
       [ "\\endhtmlonly", "commands.html#cmdendhtmlonly", null ],
       [ "\\endlatexonly", "commands.html#cmdendlatexonly", null ],
       [ "\\endmanonly", "commands.html#cmdendmanonly", null ],
@@ -408,23 +408,23 @@ var NAVTREE =
       [ "\\f{environment}{", "commands.html#cmdfcurlyopen", null ],
       [ "\\f}", "commands.html#cmdfcurlyclose", null ],
       [ "\\htmlonly['[block]']", "commands.html#cmdhtmlonly", null ],
-      [ "\\image['{'option[,option]'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
+      [ "\\image['{'option[,option]'}'] &lt;format&gt; &lt;file&gt; [\"caption\"] [&lt;sizeindication&gt;=&lt;size&gt;]", "commands.html#cmdimage", null ],
       [ "\\latexonly", "commands.html#cmdlatexonly", null ],
       [ "\\manonly", "commands.html#cmdmanonly", null ],
       [ "\\li { item-description }", "commands.html#cmdli", null ],
       [ "\\n", "commands.html#cmdn", null ],
-      [ "\\p <word>", "commands.html#cmdp", null ],
+      [ "\\p &lt;word&gt;", "commands.html#cmdp", null ],
       [ "\\rtfonly", "commands.html#cmdrtfonly", null ],
       [ "\\verbatim", "commands.html#cmdverbatim", null ],
       [ "\\xmlonly", "commands.html#cmdxmlonly", null ],
       [ "\\\\", "commands.html#cmdbackslash", null ],
       [ "\\@", "commands.html#cmdat", null ],
       [ "\\~[LanguageId]", "commands.html#cmdtilde", null ],
-      [ "\\&", "commands.html#cmdamp", null ],
+      [ "\\&amp;", "commands.html#cmdamp", null ],
       [ "\\$", "commands.html#cmddollar", null ],
       [ "\\#", "commands.html#cmdhash", null ],
-      [ "\\<", "commands.html#cmdlt", null ],
-      [ "\\>", "commands.html#cmdgt", null ],
+      [ "\\&lt;", "commands.html#cmdlt", null ],
+      [ "\\&gt;", "commands.html#cmdgt", null ],
       [ "\\%", "commands.html#cmdperc", null ],
       [ "\\\"", "commands.html#cmdquot", null ],
       [ "\\.", "commands.html#cmdchardot", null ],
@@ -457,7 +457,11 @@ var NAVTREE =
     ] ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.14 Series", "changelog.html#log_1_14", [
+        [ "Release 1.14.0", "changelog.html#log_1_14_0", null ]
+      ] ],
       [ "1.13 Series", "changelog.html#log_1_13", [
+        [ "Release 1.13.2", "changelog.html#log_1_13_2", null ],
         [ "Release 1.13.1", "changelog.html#log_1_13_1", null ],
         [ "Release 1.13.0", "changelog.html#log_1_13_0", null ]
       ] ],
@@ -522,8 +526,9 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "additional.html",
-"commands.html#cmdsection"
+"commands.html#cmdrtfonly"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
-var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
+var SYNCOFFMSG = 'click to enable panel synchronization';
+var LISTOFALLMEMBERS = 'List of all members';
\ No newline at end of file
